%global momorel 2

%{!?octave_api: %define octave_api %(octave-config -p API_VERSION || echo 0)}

## Octave-forge installs in a directory tree specific to the installed
## version of octave, so the following version dependency is necessary.
#%%global octave_ver %(rpm -q --qf '%%{version}' octave)
%global octave_ver 3.0.1

Name:           octave-forge
Version:        20080831
Release:	%{momorel}m%{?dist}
Summary:        Contributed functions for octave
Group:          Applications/Engineering
License:        GPL and BSD
URL:            http://octave.sourceforge.net/
Source0:        http://dl.sourceforge.net/sourceforge/octave/%{name}-bundle-%{version}.tar.gz
NoSource:	0
Patch0:		octave-forge-20080831-no_escape.patch
Patch1:		octave-forge-20080831-va_list.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires:	octave = %{octave_ver} 
Requires:	ImageMagick >= 6.4.2.1
Requires:       qhull netcdf hdf5 ginac fftw3 gsl
BuildRequires:  octave-devel = %{octave_ver} gcc-gfortran
BuildRequires:  fftw3-devel gsl-devel qhull-devel netcdf hdf5-devel
#BuildRequires:  xorg-x11-devel 
BuildRequires:  libjpeg-devel libpng-devel zlib-devel
BuildRequires:  ncurses-devel >= 5.6-10 tetex
BuildRequires:  readline-devel >= 5.0
BuildRequires:  pcre-devel
BuildRequires:  cln-devel >= 1.2.2
BuildRequires:  ginac-devel >= 1.4.1
BuildRequires:  ftplib-devel

%description
Octave-forge is a community project for collaborative development of
octave extensions. The extensions in this package include additional
data types such as sparse matrices, and functions for a variety of
different applications including signal and image processing,
communications, control, optimization, statistics, geometry, and
symbolic math.

%prep
%setup -q -n octave-forge-bundle-%{version}

# The scripts below will build everything automatically, so first
# remove some packages that we don't want to build:
# 1. video stuff requires non-free libraries
rm main/video-*.tar.gz
# 2. engine is not a real octave package
rm extra/engine-*.tar.gz
# 3. jhandles depends on jogl, which is forbidden from Fedora
rm extra/jhandles-*.tar.gz
# 4. other OS stuff
rm extra/windows-*.tar.gz
# 5. exclude database stuff--it should be in its own package
# rm main/database-*.tar.gz


#Unpack everything
for pkg in main extra language
do
   cd $pkg
   for tgz in *.tar.gz
   do
      tar xzf $tgz

      #Collect provides
      echo $tgz | sed 's/\(.*\)-\([0-9]*\.[0-9]*\.[0-9]*\)\.tar\.gz/Provides: octave-\1 = \2/' >> ../octave-forge-provides
   done
   cd ..
done

#Cleanup some CVS directories
find -name CVS | xargs rm -rf

#Install with -nodeps
sed -i -e "s/pkg('install',/pkg('install','-nodeps',/" */*/Makefile

#Fix permissions
find -name COPYING -o -name INDEX -o -name DESCRIPTION -o -name \*.m | xargs chmod -x

#Fix line endings
find -name \*.m | xargs dos2unix

# database build
%patch0 -p1 -b .no_escape
%patch1 -p1 -b .va_list
sed -i 's/-lmysqlclient/-lmysqlclient -L\/usr\/%{_lib}\/mysql\//g' main/database*/src/Makefile

# image build
sed -i 's/--cppflags/--cppflags | sed "s\/-fopenmp\/\/g"/g' main/image-*/src/Makefile


%build
rm -rf /tmp/%{name}
mkdir /tmp/%{name}

export TERM=""
for pkg in main extra language
do
   cd $pkg
   for dir in *.[0-9]
   do
      cd $dir
      if [ -f configure ]
      then
         %configure
      elif [ -f src/configure ]
      then
         cd src
         %configure
         cd ..
      fi
      if [ -f Makefile ]
      then
         make TMPDIR=/tmp/%{name}
      elif [ -f src/Makefile ]
      then
         cd src
         make TMPDIR=/tmp/%{name}
         cd ..
      fi
      cd ..
   done
   cd ..
done

%install
rm -rf %{buildroot}
export TERM=""

for pkg in main extra language
do
   cd $pkg
   for dir in *.[0-9]
   do
       cd $dir
       make install TMPDIR=/tmp/%{name} DESTDIR=%{buildroot} DISTPKG=momonga
       cd ..
   done
   cd ..
done

##Move aurecord to arch-dependent dir
#archdir=%{_libexecdir}/octave/packages/`octave-config -p CANONICAL_HOST_TYPE`-%{octave_api}
#audiover=`basename %{buildroot}%{_datadir}/octave/packages/audio-*`
#mkdir -p %{buildroot}${archdir}/${audiover}
#mv %{buildroot}%{_datadir}/octave/packages/${audiover}/bin \
 #  %{buildroot}${archdir}/${audiover}/

%clean
rm -rf /tmp/%{name}
rm -rf %{buildroot}

%post
octave -q -H --no-site-file --eval "pkg('rebuild');"

%postun
octave -q -H --no-site-file --eval "pkg('rebuild');"

%files
%defattr(-,root,root)
%{_datadir}/octave/packages/*
%{_libexecdir}/octave/packages

%changelog
* Fri Sep 19 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (20080831-2m)
- add patch1 for va_list (database)

* Thu Sep 18 2008 Yohsuke Ooi <meke@momonga-linux.org> 
- (20080831-1m)
- update 20080831.
-- support current MySQL, ImageMagick

* Sun Jul 13 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (20080429-2m)
- rebuild against ImageMagick-6.4.2.1

* Fri Jul 11 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (20080429-1m)
- version down to 20080429, 20080507 can not build on x86_64

* Thu Jun 12 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (20080507-3m)
- apply Patch10 for x86_64, too

* Sat Jun 01 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (20080507-2m)
- rm -rf database-1.0.tar.gz if x86_64

* Fri May 30 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (20080507-1m)
- update to 20080507

* Sun Apr 27 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (20080216-4m)
- add disable_java patch for x86_64

* Wed Apr 23 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (20080216-3m)
- set octave_ver 3.0.1 to resolve dependency

* Thu Apr 17 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (20080216-2m)
- rebuild against cln-1.2.2

* Mon Apr 14 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (20080216-1m)
- update to 20080216
- rebuild against hdf5-1.8.0

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (20071212-5m)
- rebuild against gcc43

* Sun Feb 17 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (20071212-4m)
- rebuild against cln-1.2.0 and ginac-devel-1.4.1
- set octave_api

* Thu Feb 14 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (20071212-3m)
- do not use $tmppath

* Fri Feb  8 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (20071212-2m)
- rebuild against ncurses-5.6-10m

* Tue Dec 25 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (20071212-1m)
- update 2007.12.12

* Thu May 31 2007 Masayuki SANO <nosanosa@momonga-linux.org>
- (2006.07.09-2m)
- rebuild for octave-2.9.12

* Sun Nov 12 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (2006.07.09-1m)
- update to octave-2.9.9/octave-forge-2006.07.09
- (changelog in Fedora)
- * Mon Nov 06 2006 Jindrich Novy <jnovy@redhat.com> 2006.07.09-8
- - rebuild against the new curl
- 
- * Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 2006.07.09-7
-  - rebuilt for unwind info generation, broken in gcc-4.1.1-21
- 
- * Sat Sep 23 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-6
- - Rebuild for updated libdap.
- 
- * Fri Sep 15 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-5
- - Rebuild for FC6.
- 
- * Fri Aug 25 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-4
- - New build for octave 2.9.8.
- - Patch bug in imread.m
- - Patch LOADPATH bug.
- - Fix configure command so that m files containing paths are
-   correctly generated.
- 
- * Tue Jul 11 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-3
- - New build for octave 2.9.7.
- - Disable mex related functions (they are in octave now).
- 
- * Tue Jul 11 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-2
- - Patch legend.m.
- 
- * Mon Jul 10 2006 Quentin Spencer <qspencer@users.sf.net> 2006.07.09-1
- - New release. Old patches and associated specfile cruft removed.
- 
- * Wed May  3 2006 Quentin Spencer <qspencer@users.sf.net> 2006.03.17-4
- - Bug fix for #190481
- 
- * Thu Apr 27 2006 Quentin Spencer <qspencer@users.sf.net> 2006.03.17-3
- - Add fixes for octcdf (from the author), which changes the dependency
-   from netcdf to libnc-dap. (This requires autoconf temporarily.)
- 
- * Wed Apr 19 2006 Quentin Spencer <qspencer@users.sf.net> 2006.03.17-2
- - New release for octave 2.9.5.
- - Patch added for incompatibilities between octave 2.9.4 and 2.9.5.

* Thu Jul  6 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (2006.03.17-4m)
- rebuild against readline-5.0

* Thu Jun  8 2006 Kazuhiko <kazuhiko@fdiary.net>
- (2006.03.17-3m)
- BuildRequires: texi2html -> tetex

* Wed Jun 07 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (2006.03.17-2m)
- revised %%files to avoid a confriction of directries with octave

* Wed May 17 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (2006.03.17-1m)
- import to Momonga
- - this package provides MatLab compatibility to some extent.

* Thu Apr 20 2006 Masayuki SANO <sbfield_snmsyk@yahoo.co.jp>
- (2006.03.17-0.0.1m)
- update to 2006.03.17

* Tue Jun 28 2005 Masayuki SANO <sbfield_snmsyk@yahoo.co.jp>
- (2005.06.13-0.0.1m)
- build for Momonga
- based on octave-forge-2005.06.13-6.fc4.src.rpm

* Wed Jun 22 2005 Quentin Spencer <qspencer@users.sf.net> 2005.06.13-6
- Rebuild.

* Fri Jun 17 2005 Quentin Spencer <qspencer@users.sf.net> 2005.06.13-1
- New upstream release. Now requires pcre-devel to build.
- Corrected instructions on creating patched source tarball.
- Cleanup of unneeded things in build section
- Add patch for problem with main/plot/legend.m
- Add fftw3-devel to BuildRequires.

* Fri Jun  3 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-8
- Remove explicit BuildRequires for c++ compiler and libs
  (not needed and causes build failure in the build system for x86_64).

* Mon Apr 25 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-7
- Changed license (some functions are GPL, BSD, and public domain,
  so the collection is licensed as public domain).
- Moved ugly path hacks from build to install so that RPM_BUILD_ROOT
  doesn't end up in the code (which it did before).
- Replaced upstream tarball with patched version that removed GPL
  incompatible code.

* Thu Apr 21 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-6
- Added GiNaC-devel BuildRequires

* Tue Mar 29 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-5
- Rebuild for octave-2.1.69

* Mon Mar 28 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-4
- Rebuild for octave-2.1.68

* Thu Feb 24 2005 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-3
- Updated spec file to get octave version at build time.

* Wed Nov 17 2004 Quentin Spencer <qspencer@users.sf.net> 2004.11.16-2
- Revised package description.

* Tue Jun 15 2004 Quentin Spencer <qspencer@users.sf.net>
- Added qhull support.

* Tue Feb  4 2003 Quentin Spencer <qspencer@users.sf.net>
- First Version, loosely based on Red Hat's spec file for octave.
